<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

class Zakeke_Order {

	/**
	 * Setup class.
	 */
	public static function init() {
		add_action( 'woocommerce_add_order_item_meta', array( __CLASS__, 'add_order_item_meta' ), 20, 2 );
		add_action( 'woocommerce_thankyou', array( __CLASS__, 'new_order' ), 20 );
		add_action( 'woocommerce_order_item_meta_start', array( __CLASS__, 'order_item_meta_start' ), 20, 3 );
	}

	public function add_order_item_meta( $item_id, $values ) {
		if ( isset( $values['zakeke_data'] ) ) {
			wc_add_order_item_meta( $item_id, 'zakeke_data', $values['zakeke_data'] );
		}
	}

	public static function new_order( $order_id ) {
		$order = wc_get_order( $order_id );

        if ( $order->get_meta( 'zakeke_placed_order', true ) ) {
            return;
        }

		$items = $order->get_items();

		$data = array(
			'orderCode'     => $order_id,
			'sessionID'     => get_current_user_id(),
			'total'         => $order->get_total(),
			'orderStatusID' => 1,
			'details'       => array()
		);

		$guestCode = zakeke_guest_code();
		if ( $order->get_customer_id() > 0 ) {
			$data['customerID'] = $order->get_customer_id();
		} elseif ( $guestCode ) {
			$data['visitorID'] = $guestCode;
		}

		foreach ( $items as $order_item_id => $item ) {
			$zakeke_data = $item->get_meta( 'zakeke_data' );

			if ( ! $zakeke_data ) {
				continue;
			}

			$item_data = array(
				'designDocID'     => $zakeke_data['design'],
				'orderDetailCode' => $order_item_id,
				'quantity'        => absint( $item['qty'] ),
				'designUnitPrice' => $zakeke_data['price_excl_tax'],
				'modelUnitPrice'  => $zakeke_data['original_final_excl_tax_price']
			);

			$data['details'][] = $item_data;
		}

		if ( count( $data['details'] ) > 0 ) {
			$webservice = new Zakeke_Webservice();
			$webservice->place_order( $data );

			$order->add_meta_data( 'zakeke_placed_order', true );
			$order->save();
		}
	}

	public static function order_item_meta_start( $item_id, $item, $order ) {
		if ( $zakeke_data = $item->get_meta( 'zakeke_data' ) ) {
			?>
            <ul class="wc-item-meta">
                <li><strong class="wc-item-meta-label"><?php _e( 'Customization', 'zakeke' ) ?>:</strong><img
                            src="<?php echo esc_url( $zakeke_data['previews'][0]->url ) ?>"/></li>
				<?php if ( $zakeke_data['price_tax'] > 0.0 ) : ?>
                    <li><strong class="wc-item-meta-label"><?php _e( 'Customization Price', 'zakeke' ) ?>
                            :</strong> <?php echo wc_price( $zakeke_data['price_tax'] ) ?></li>
				<?php endif ?>
            </ul>
			<?php
        }
	}
}

Zakeke_Order::init();
