<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Zakeke_Designer Class.
 */
class Zakeke_ProductPage {

	/**
	 * Setup class.
	 */
	public static function init() {
		$integration = new Zakeke_Integration();

        add_filter( 'woocommerce_product_supports', array( __CLASS__, 'no_ajax_add_to_cart' ), 20, 3 );

        add_action( 'wp_enqueue_scripts', array( __CLASS__, 'enqueue_scripts' ) );

		if ( 'yes' === $integration->force_customization ) {
			add_filter( 'woocommerce_product_add_to_cart_text', array( __CLASS__, 'add_to_cart_text' ), 20, 2 );
			add_filter( 'woocommerce_product_single_add_to_cart_text', array( __CLASS__, 'single_add_to_cart_text' ),
				20, 2 );
			add_filter( 'woocommerce_product_add_to_cart_url', array( __CLASS__, 'add_to_cart_url' ), 30, 2 );
		} else {
			add_action( 'woocommerce_before_single_product', array( __CLASS__, 'product_page' ) );
		}

		add_action( 'woocommerce_after_add_to_cart_button', array( __CLASS__, 'add_customize_input' ) );
	}

	public static function no_ajax_add_to_cart( $enabled, $feature, $product ) {
		if ( 'ajax_add_to_cart' == $feature && zakeke_is_customizable( $product->get_id() ) ) {
			$enabled = false;
		}

		return $enabled;
	}

	public static function enqueue_scripts() {
		wp_register_script( 'zakeke-product-page', get_zakeke()->plugin_url() . '/assets/js/frontend/product-page.js',
			array(), ZAKEKE_VERSION, false );
        wp_enqueue_script( 'zakeke-product-page' );
	}

	public static function product_page() {
		global $product;

		if ( ! zakeke_is_customizable( $product->get_id() ) ) {
			return;
		}

		add_action( 'woocommerce_before_add_to_cart_button', array( __CLASS__, 'add_customize_button' ), 25 );
	}

	public static function add_customize_button() {
		?>
        <div class="group">
            <button class="zakeke-customize-button button" type="button" class=" button "><?php _e( 'Customize',
                    'zakeke' ) ?></button>
        </div>
		<?php
	}

	public static function add_customize_input() {
		global $product;

		if ( ! zakeke_is_customizable( $product->get_id() ) ) {
			return;
		}

		$integration = new Zakeke_Integration();
		if ( 'yes' === $integration->force_customization ) {
			?>
            <input type="hidden" name="zakeke_design" id="zakeke_design" value="new"/>
			<?php
		} else {
			?>
            <input type="hidden" name="zakeke_design" id="zakeke_design"/>
			<?php
		}
	}

	public static function single_add_to_cart_text( $text, $product ) {
		if ( zakeke_is_customizable( $product->get_id() ) ) {
			$text = __( 'Customize', 'zakeke' );
		}

		return $text;
	}

	public static function add_to_cart_text( $text, $product ) {
		if ( 'simple' === $product->get_type() && zakeke_is_customizable( $product->get_id() ) ) {
			$text = __( 'Customize', 'zakeke' );
		}

		return $text;
	}

	public static function add_to_cart_url( $url, $product ) {
		$product_id = $product->get_id();
		if ( 'simple' === $product->get_type() && zakeke_is_customizable( $product_id ) ) {
			$url = get_permalink( $product_id ) . '?zakeke_design=new&add-to-cart=' . $product->get_id();
		}

		return $url;
	}
}

Zakeke_ProductPage::init();
